# coding: utf-8

"""
    Cisco-Reservable-SD-WAN

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_client.paths.dataservice_template_policy_list.get import DataserviceTemplatePolicyListGet
from openapi_client.paths.dataservice_template_policy_vedge_devices.get import DataserviceTemplatePolicyVedgeDevicesGet


class SDWANDevicePolicyApi(
    DataserviceTemplatePolicyListGet,
    DataserviceTemplatePolicyVedgeDevicesGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
