# coding: utf-8

"""
    Cisco-Reservable-SD-WAN

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_client.paths.dataservice_device_counters.get import DataserviceDeviceCountersGet
from openapi_client.paths.dataservice_device.get import DataserviceDeviceGet
from openapi_client.paths.dataservice_device_monitor.get import DataserviceDeviceMonitorGet
from openapi_client.paths.dataservice_statistics_interface.get import DataserviceStatisticsInterfaceGet


class SDWANFabricDevicesApi(
    DataserviceDeviceCountersGet,
    DataserviceDeviceGet,
    DataserviceDeviceMonitorGet,
    DataserviceStatisticsInterfaceGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
