# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_client.paths.dataservice_template_feature_types import Api

from openapi_client.paths import PathValues

path = PathValues.DATASERVICE_TEMPLATE_FEATURE_TYPES